pub struct CrdTranslateOperation<'c> { /* private fields */ }Expand description
A crd_translate operation. Performs coordinate translation between level and dimension coordinate space..
Performs coordinate translation between level and dimension coordinate space according to the affine maps defined by $encoder.
Example:
%l0, %l1, %l2, %l3 = sparse_tensor.crd_translate dim_to_lvl [%d0, %d1] as #BSR
: index, index, index, indexImplementations
Sourceimpl<'c> CrdTranslateOperation<'c>
impl<'c> CrdTranslateOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> CrdTranslateOperationBuilder<'c, Unset, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> CrdTranslateOperationBuilder<'c, Unset, Unset, Unset, Unset>
Creates a builder.
pub fn out_crds(&self) -> impl Iterator<Item = OperationResult<'c, '_>>
pub fn in_crds(&self) -> impl Iterator<Item = Value<'c, '_>>
pub fn direction(&self) -> Result<Attribute<'c>, Error>
pub fn set_direction(&mut self, value: Attribute<'c>)
pub fn encoder(&self) -> Result<Attribute<'c>, Error>
pub fn set_encoder(&mut self, value: Attribute<'c>)