pub struct ToPositionsOperation<'c> { /* private fields */ }Expand description
A positions operation. Extracts the level-th positions array of the tensor.
Returns the positions array of the tensor’s storage at the given
level. This is similar to the bufferization.to_buffer operation
in the sense that it provides a bridge between a tensor world view
and a bufferized world view. Unlike the bufferization.to_buffer
operation, however, this sparse operation actually lowers into code
that extracts the positions array from the sparse storage itself
(either by calling a support library or through direct code).
Writing into the result of this operation is undefined behavior.
Example:
%1 = sparse_tensor.positions %0 { level = 1 : index }
: tensor<64x64xf64, #CSR> to memref<?xindex>Implementations
Sourceimpl<'c> ToPositionsOperation<'c>
impl<'c> ToPositionsOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ToPositionsOperationBuilder<'c, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ToPositionsOperationBuilder<'c, Unset, Unset>
Creates a builder.
pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn tensor(&self) -> Result<Value<'c, '_>, Error>
pub fn level(&self) -> Result<IntegerAttribute<'c>, Error>
pub fn set_level(&mut self, value: IntegerAttribute<'c>)